requestState method
Request the state of the awareness from the server
Implementation
void requestState(String documentId) {
unawaited(
client.sendMessage(
AwarenessQueryMessage(
documentId: documentId,
),
),
);
}
Request the state of the awareness from the server
void requestState(String documentId) {
unawaited(
client.sendMessage(
AwarenessQueryMessage(
documentId: documentId,
),
),
);
}