client library

Client library for CRDT Socket Sync

Classes

AwarenessMessage
base class for awareness messages
AwarenessQueryMessage
message to query the awareness state
AwarenessStateMessage
message with the awareness state
AwarenessUpdateMessage
message to update the awareness state
ChangeMessage
Message containing a CRDT change.
ChangesMessage
Message containing a set of changes.
ClientAwareness
Client awareness state
ClientAwarenessPlugin
Client awareness plugin
ClientSyncPlugin
Base class for all client plugins.
CompressedCodec<T>
Codec for messages with optional compression
Compressor
Interface for data compression
CRDTSocketClient
Interface for the CRDT client
DocumentAwareness
Document awareness state
DocumentStatusMessage
Message containing a full snapshot.
DocumentStatusRequestMessage
Snapshot request message sent from client to server.
ErrorMessage
Error message.
HandshakeRequestMessage
Handshake request message sent from client to server.
HandshakeResponseMessage
Handshake response message sent from server to client.
JsonMessageCodec<T>
A message codec that uses JSON for serialization.
Message
Base class for all messages exchanged over a connection.
MessageCodec<T>
Interface for encoding and decoding messages
MessageTypeValue
Marker interface for a message type's integer code.
NoCompression
No compression implementation
OutboundQueue
A serialized, byte-bounded outbound send queue.
PingMessage
Ping message to check the connection.
PluginAwareMessageCodec
A message codec that can be used to encode and decode messages for a list of MessageCodecs.
PongMessage
Pong message.
Protocol
Class that handles the communication protocol.
SessionEventChangeApplied
Session event for a change applied to the server document.
SyncManager
Manager for the CRDT client
SyncMessage
Base class for the CRDT-aware sync protocol messages (server-client mode).
SyncPlugin
Base class for all server and client plugins.
SyncSessionEvent
Base class for the server-client (CRDT-aware) session events.
SyncSessionEventGeneric
Session event for a generic sync event (handshake completed, document status created, client out of sync).
Transport
An interface for transporting messages, define the methods necessary to send and receive messages, independently from the underlying transport mechanism.
TransportConnection
An interface for transporting messages, define the methods necessary to send and receive messages, independently from the underlying transport mechanism.
TransportConnector
An interface for the transport connection

Enums

AwarenessMessageType
Awareness message types
ConnectionStatus
Enum that represents the status of the connection
MessageType
Core protocol message types (range 0-19).
SyncSessionEventType
Session event types of the CRDT-aware sync protocol (server-client mode).

Mixins

SocketClientProvider
A provider that can provide the client instance.

Exceptions / Errors

OutboundBufferOverflow
Thrown when an OutboundQueue would exceed its byte bound.