SyncManager class

Manager for the CRDT client

it's responsible for:

  • implementing the requested changes to the document
  • submitting the changes to the document

Constructors

SyncManager({required CRDTDocument document, required CRDTSocketClient client})
Manager for the CRDT client

Properties

client CRDTSocketClient
The socket client
final
document → CRDTDocument
The local CRDT document
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyChange(Change change) → void
Applies a change
applyChanges(List<Change> changes) → void
Applies a list of changes
dispose() → void
Dispose the resources
import({required VersionVector serverVersionVector, List<Change>? changes, Snapshot? snapshot}) → void
CRDTDocument.import with:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestDocumentStatus() Future<void>
Requests the document status from the server
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited