ClientSyncPlugin class abstract

Base class for all client plugins.

extends (not implements) this class to make the plugin work.

Once the plugin is attached to the client the CRDTSocketClient will be available.

Implemented types
Mixed-in types
Implementers

Constructors

ClientSyncPlugin()

Properties

client CRDTSocketClient
The client instance.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
messageCodec MessageCodec<Message>
The message codec for the plugin.
no setterinherited
name String
The name of the plugin.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Called when the plugin is disposed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnected() → void
Called when the client is connected.
onDisconnected() → void
Called when the client is disconnected.
onMessage(Message message) → void
Called when a message is received from the server.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited