lastKnownSeq property
int
get
lastKnownSeq
The last relay log sequence number this client knows to have fully
imported (0 before the first welcome).
Implementation
int get lastKnownSeq;
The last relay log sequence number this client knows to have fully
imported (0 before the first welcome).
int get lastKnownSeq;