RelayAckMessage class

Acknowledgement of a RelayPushMessage, relay to client.

Inheritance

Constructors

RelayAckMessage({required String documentId, required int seq, required int count, required int logLength, required bool compact})
Constructor
const
RelayAckMessage.fromJson(Map<String, dynamic> json)
Create an ack message from a JSON map
factory

Properties

compact bool
Whether the relay asks this client to upload a snapshot (see RelaySnapshotUploadMessage)
final
count int
How many blobs were persisted by this ack
final
documentId String
The document ID to which the message refers
finalinherited
hashCode int
The hash code for this object.
no setterinherited
logLength int
The current room log length
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
The last sequence number assigned to the acknowledged blobs
final
type MessageTypeValue
The message type
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize the message to a JSON string
inherited
toJson() Map<String, dynamic>
Convert the message to a JSON map
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited