compact property
Whether the relay asks this client to upload a snapshot (see RelaySnapshotUploadMessage)
Implementation
final bool compact;
Whether the relay asks this client to upload a snapshot (see RelaySnapshotUploadMessage)
final bool compact;