RelayChangesMessage class

Change blobs rebroadcast from relay to the other clients in the room.

Inheritance

Constructors

RelayChangesMessage({required String documentId, required List<String> changes, required int seq, String? from})
Constructor
const
RelayChangesMessage.fromJson(Map<String, dynamic> json)
Create a changes message from a JSON map
factory

Properties

changes List<String>
The rebroadcast change blobs (opaque base64), one per CRDT change
final
documentId String
The document ID to which the message refers
finalinherited
from String?
The session id of the client that pushed the changes, if known
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
The last sequence number assigned to the rebroadcast blobs.
final
type MessageTypeValue
The message type
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize the message to a JSON string
inherited
toJson() Map<String, dynamic>
Convert the message to a JSON map
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited