RelayHelloMessage class

Join request sent from client to relay after connecting.

Inheritance

Constructors

RelayHelloMessage({required String documentId, required PeerId author})
Constructor
const
RelayHelloMessage.fromJson(Map<String, dynamic> json)
Create a hello message from a JSON map
factory

Properties

author → PeerId
The author of the joining client
final
documentId String
The document ID to which the message refers
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MessageTypeValue
The message type
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize the message to a JSON string
inherited
toJson() Map<String, dynamic>
Convert the message to a JSON map
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited