RelayLogEntry class

One persisted opaque change blob of a relay room log.

Constructors

RelayLogEntry({required int seq, required String blob})
Constructor
const

Properties

blob String
The change payload (opaque base64)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
Sequence number assigned by the relay (monotonically increasing per room, starting at 1)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited