RelayPushMessage class

Change blobs pushed from client to relay.

Inheritance

Constructors

RelayPushMessage({required String documentId, required List<String> changes})
Constructor
const
RelayPushMessage.fromJson(Map<String, dynamic> json)
Create a push message from a JSON map
factory

Properties

changes List<String>
The pushed change blobs (opaque base64), one per CRDT change
final
documentId String
The document ID to which the message refers
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MessageTypeValue
The message type
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize the message to a JSON string
inherited
toJson() Map<String, dynamic>
Convert the message to a JSON map
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited