RelaySessionEventChangesPushed class

Session event for change blobs pushed to a relay room.

The relay server broadcasts the blobs to the other clients in the room when this event is emitted.

Inheritance

Constructors

RelaySessionEventChangesPushed({required String sessionId, required String message, required String documentId, required List<String> changes, required int seq})
Constructor
const

Properties

changes List<String>
The pushed change blobs (opaque base64)
final
documentId String
The room id
final
hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with the event
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
The last sequence number assigned to the pushed blobs
final
sessionId String
The session id
finalinherited
type RelaySessionEventType
The event type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited