RelaySessionEventJoined class

Session event for a client that joined a relay room.

Inheritance

Constructors

RelaySessionEventJoined({required String sessionId, required String message, required String documentId, required PeerId author})
Constructor
const

Properties

author → PeerId
The author of the joining client
final
documentId String
The room id
final
hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with the event
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
The session id
finalinherited
type RelaySessionEventType
The event type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited