RelayWelcomeMessage class

Join response sent from relay to client.

Inheritance

Constructors

RelayWelcomeMessage({required String documentId, required String sessionId, required List<String> changes, required int seq, required int logLength, required bool compact, String? snapshot})
Constructor
const
RelayWelcomeMessage.fromJson(Map<String, dynamic> json)
Create a welcome message from a JSON map
factory

Properties

changes List<String>
The room change log after snapshot (opaque base64 blobs)
final
compact bool
Whether the relay asks this client to upload a snapshot (see RelaySnapshotUploadMessage)
final
documentId String
The document ID to which the message refers
finalinherited
hashCode int
The hash code for this object.
no setterinherited
logLength int
The current room log length
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
The last sequence number assigned by the relay for this room
final
sessionId String
The session id assigned to the client by the relay
final
snapshot String?
The latest room snapshot (opaque base64), if any
final
type MessageTypeValue
The message type
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize the message to a JSON string
inherited
toJson() Map<String, dynamic>
Convert the message to a JSON map
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited