DefaultWebSocketServerTransformer class
Default WebSocketServerTransformer, backed by dart:io's
WebSocketTransformer.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isUpgradeRequest(
HttpRequest request) → bool -
Check if the request is an upgrade request
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upgrade(
HttpRequest request) → Future< WebSocket> -
Upgrade the request to a WebSocket connection
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited