versionVector property

VersionVector? versionVector
final

The sender's current version vector, if reported.

Clients piggy-back their version vector on pings so the server can learn how far each client has advanced and take a snapshot (and prune history) once every connected client has confirmed a common frontier.

Implementation

final VersionVector? versionVector;