PluginAwareMessageCodec constructor

const PluginAwareMessageCodec(
  1. List<MessageCodec<Message>> _codecs
)

A message codec that can be used to encode and decode messages for a list of MessageCodecs.

The codec will try to decode the message with each MessageCodec until one of them succeeds. If no MessageCodec can decode the message, the codec will return null.

This codec is designed to support the plugin system. It is used to encode and decode messages with the default codec and the plugins' codecs.

Constructor

Implementation

const PluginAwareMessageCodec(this._codecs);