SessionEventChangeApplied class

Session event for a change applied to the server document.

Inheritance

Constructors

SessionEventChangeApplied({required String sessionId, required String message, required Change change, required String documentId})
Constructor
const

Properties

change → Change
The change that was received
final
documentId String
The document id
final
hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with the event
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
The session id
finalinherited
type SyncSessionEventType
The event type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited