SyncSessionEvent class abstract
Base class for the server-client (CRDT-aware) session events.
- Inheritance
-
- Object
- SessionEvent
- SyncSessionEvent
- Implementers
Constructors
- SyncSessionEvent({required String sessionId, required String message, required SyncSessionEventType type})
-
Constructor
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message associated with the event
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
The session id
finalinherited
- type → SyncSessionEventType
-
The event type
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited