snapshots property
Stream<ServerSnapshot>
get
snapshots
The snapshots the tracked documents take, once start has run.
Implementation
Stream<ServerSnapshot> get snapshots => _controller.stream;
The snapshots the tracked documents take, once start has run.
Stream<ServerSnapshot> get snapshots => _controller.stream;