snapshotsByDocument property

Map<String, Snapshot> get snapshotsByDocument

Get a copy of all snapshots (for debugging/testing purposes)

Named for what it holds, not snapshots: the durable registry uses that name for a stream of the snapshots as they are taken, and one name for two unrelated things on one interface is a trap.

Implementation

Map<String, Snapshot> get snapshotsByDocument => Map.unmodifiable(_snapshots);