RelaySnapshotRecord class

The latest snapshot of a relay room.

Constructors

RelaySnapshotRecord({required String blob, required int upToSeq})
Constructor
const

Properties

blob String
The snapshot payload (opaque base64)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upToSeq int
The last log sequence number covered by this snapshot
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited