onMessage abstract method

void onMessage(
  1. Message message
)

Called when a message is received from the server.

The plugin can then react to the message, for example by sending a response to the server.

Implementation

void onMessage(Message message);