compactRetryInterval constant

Duration const compactRetryInterval

Minimum time between two compaction requests for the same room.

Rate-limits the compact flag so only one client at a time is asked to upload a snapshot.

Implementation

static const Duration compactRetryInterval = Duration(seconds: 30);