logCompactThreshold constant

int const logCompactThreshold

Room log length beyond which the relay asks a client to upload a snapshot to compact the log.

Implementation

static const int logCompactThreshold = 200;