RelaySessionEventSnapshotUploaded class
Session event for a snapshot uploaded to compact a relay room log.
- Inheritance
-
- Object
- SessionEvent
- RelaySessionEvent
- RelaySessionEventSnapshotUploaded
Constructors
- RelaySessionEventSnapshotUploaded({required String sessionId, required String message, required String documentId, required int upToSeq})
-
Constructor
const
Properties
- documentId → String
-
The room id
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message associated with the event
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
The session id
finalinherited
- type → RelaySessionEventType
-
The event type
no setterinherited
- upToSeq → int
-
The last log sequence number covered by the uploaded snapshot
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited