RelaySnapshotUploadMessage class
Snapshot uploaded from client to relay to compact the room log.
- Inheritance
-
- Object
- Message
- RelayMessage
- RelaySnapshotUploadMessage
Constructors
- RelaySnapshotUploadMessage({required String documentId, required String snapshot, required int upToSeq})
-
Constructor
const
-
RelaySnapshotUploadMessage.fromJson(Map<
String, dynamic> json) -
Create a snapshot upload message from a JSON map
factory
Properties
- documentId → String
-
The document ID to which the message refers
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshot → String
-
The uploaded snapshot (opaque base64)
final
- type → MessageTypeValue
-
The message type
finalinherited
- upToSeq → int
-
The log sequence number covered by snapshot: the relay deletes the
log entries with a sequence number less than or equal to it
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → String -
Serialize the message to a JSON string
inherited
-
toJson(
) → Map< String, dynamic> -
Convert the message to a JSON map
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited