handleUndecodable method
Called for an incoming data frame no codec could decode.
The default reports a SessionEventType.error event. Sessions may override it to answer the peer (for example, a relay session diagnoses a CRDT-aware sync client that connected to the wrong server).
Implementation
@protected
void handleUndecodable(List<int> data) {
addSessionEvent(
SessionEventGeneric(
sessionId: id,
type: SessionEventType.error,
message: 'Failed to decode message: $data. '
'This message is not supported by any plugin.',
),
);
}