SyncSessionEventGeneric class
Session event for a generic sync event (handshake completed, document status created, client out of sync).
- Inheritance
-
- Object
- SessionEvent
- SyncSessionEvent
- SyncSessionEventGeneric
Constructors
-
SyncSessionEventGeneric({required String sessionId, required String message, required SyncSessionEventType type, Map<
String, dynamic> ? data}) -
Constructor
const
Properties
-
data
→ Map<
String, dynamic> ? -
The data associated with the event
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message associated with the event
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
The session id
finalinherited
- type → SyncSessionEventType
-
The event type
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited