add method
Remembers documentId.
Adding the same id twice is not an error.
Implementation
@override
Future<void> add(String documentId) async {
// A backend lists a document once something of it is stored, and the
// identity is the smallest thing there is.
await (await backend.peerIdStorageForDocument(documentId)).loadOrCreate();
}